e => {
  for (var _e of []);
};
{
  var a;
  {
    var _a;
  }
}
